ParseOptions

Struct ParseOptions 

pub struct ParseOptions {
    pub parse_regular_expression: bool,
    pub allow_return_outside_function: bool,
    pub preserve_parens: bool,
    pub allow_v8_intrinsics: bool,
    pub enable_ident_hashes: bool,
}
Parse options

You may provide options to the Parser using Parser::with_options.

Fields

parse_regular_expression: bool

Whether to parse regular expressions or not.

Default: false

allow_return_outside_function: bool

Allow return statements outside of functions.

By default, a return statement at the top level raises an error (false).

Default: false

preserve_parens: bool

Emit ParenthesizedExpressions and TSParenthesizedType in AST.

If this option is true, parenthesized expressions are represented by (non-standard) ParenthesizedExpression and TSParenthesizedType nodes that have a single expression property containing the expression inside parentheses.

Default: true

allow_v8_intrinsics: bool

Allow V8 runtime calls in the AST. See: V8’s Parser::ParseV8Intrinsic.

Default: false

enable_ident_hashes: bool

Precompute hashes for identifier names (Idents) in the AST.

Precomputed hashes speed up Ident-keyed hash map operations in semantic analysis and later compilation stages, at a small cost to parsing speed.

Only disable this for parse-only pipelines that never rely on Ident hashing, such as parse + serialize or formatting. Unhashed Idents do not compare equal to hashed ones, so semantic analysis and anything else relying on Ident hashing must not run on an AST parsed with this option disabled.

Default: true